@@ -1,46 +1,39 @@
-MMPC.gee = function(target, reps = NULL, group, dataset, max_k = 3, threshold = 0.05 , test = NULL, ini = NULL, wei = NULL, user_test = NULL, 
+MMPC.gee <- function(target, reps = NULL, group, dataset, max_k = 3, threshold = 0.05 , test = NULL, ini = NULL, wei = NULL, user_test = NULL, 
                          hash=FALSE, hashObject=NULL, correl = "exchangeable", se = "jack", ncores = 1) {
   ##############################
   # initialization part of MMPC #
   ##############################
-  stat_hash = NULL;
-  pvalue_hash = NULL;
+  stat_hash <- NULL
+  pvalue_hash <- NULL
   
   if ( hash )  {
-    if ( requireNamespace("hash") ) {
-      if ( is.null(hashObject) )   {
-        stat_hash = hash();
-        pvalue_hash = hash();
-      } else if (class(hashObject) == "list") {
-        stat_hash = hashObject$stat_hash;
-        pvalue_hash = hashObject$pvalue_hash;
-      } else {
-        stop('hashObject must be a list of two hash objects (stat_hash, pvalue_hash)')
-      }
-    } else {
-      cat('The hash version of SES requires the hash package');
-      return(NULL);
-    }
+    if (is.null(hashObject) )  {
+      stat_hash <- Rfast::Hash()
+      pvalue_hash <- Rfast::Hash()
+    } else if ( class(hashObject) == "list" ) {
+      stat_hash <- hashObject$stat_hash;
+      pvalue_hash <- hashObject$pvalue_hash;
+    } else   stop('hashObject must be a list of two hash objects (stat_hash, pvalue_hash)')
   }
   ###################################
   # dataset checking and initialize #
   ###################################
   if ( is.null(dataset) || is.null(target) ) {
     stop('invalid dataset or target (class feature) arguments.');
-  } else  target = target;
+  } else  target <- target;
   #check for NA values in the dataset and replace them with the variable mean
   if ( any( is.na(dataset) ) ) {
     warning("The dataset contains missing values and they were replaced automatically by the variable (column) median.")
-    dataset = apply(dataset, 2, function(x){ x[which(is.na(x))] = median(x, na.rm = TRUE) ; return(x) });
+    dataset <- apply(dataset, 2, function(x){ x[which(is.na(x))] = median(x, na.rm = TRUE) ; return(x) });
   }
   ##################################
   # target checking and initialize #
   ##################################
-  targetID = -1;
+  targetID <-  -1;
   #check if the target is a string
   if (is.character(target) & length(target) == 1) {
     findingTarget <- target == colnames(dataset);       #findingTarget <- target %in% colnames(dataset);
-    if ( !sum(findingTarget)==1 ) {
+    if ( !sum(findingTarget)== 1 ) {
       warning('Target name not in colnames or it appears multiple times');
       return(NULL);
     }
