@@ -282,7 +282,7 @@ SES <- function(target, dataset, max_k = 3, threshold = 0.05 , test = NULL, ini
 
   if ( !is.null(user_test) )   ci_test = "user_test";
   #call the main SES function after the checks and the initializations
-  results = InternalSES(target, dataset, max_k, log(threshold), test, ini, wei, user_test, hash, varsize, stat_hash, pvalue_hash, 
+  results <- InternalSES(target, dataset, max_k, log(threshold), test, ini, wei, user_test, hash, varsize, stat_hash, pvalue_hash, 
                         targetID, ncores = ncores);
   
   varsToIterate <- results$selectedVarsOrder
@@ -294,7 +294,7 @@ SES <- function(target, dataset, max_k = 3, threshold = 0.05 , test = NULL, ini
     results$selectedVars <- varsOrder[met]
     results$selectedVarsOrder <- varsOrder[met]
     results$signatures <- results$signatures[, met, drop = FALSE]
-    results$pvalues[varsToIterate] <- bc$pvalue
+    results$pvalues[varsToIterate] <- bc$pvalues
     results$n.tests <- results$n.tests + bc$counter
   }
   
