@@ -168,10 +168,8 @@ cv.waldmmpc <- function(target, dataset, wei = NULL, kfolds = 10, folds = NULL,
         }
       }
       #clear the hashmap and garbages
-      if ( !is.null(mmpcHashMap$pvalue_hash) )   hash::clear(mmpcHashMap$pvalue_hash)
-      if ( !is.null(mmpcHashMap$stat_hash) )    hash::clear(mmpcHashMap$stat_hash)
-      rm(mmpcHashMap);
-      gc();
+	  if ( !is.null(mmpcHashMap$pvalue_hash) )   mmpcHashMap$pvalue_hash <- NULL
+      if ( !is.null(mmpcHashMap$stat_hash) )     mmpcHashMap$stat_hash <- NULL
     }
     
     #finding the best performance for the metric  
