@@ -20,9 +20,9 @@ testIndGLMMGamma = function(target, reps = NULL, group, dataset, xIndex, csIndex
     csIndex2 = sort(csIndex2)
     xcs = c(xIndex,csIndex2)
     key = paste(as.character(xcs) , collapse=" ");
-    if( !is.null(stat_hash[[key]]) )  {
-      stat = stat_hash[[key]];
-      pvalue = pvalue_hash[[key]];
+    if( !is.null(stat_hash[key]) )  {
+      stat = stat_hash[key];
+      pvalue = pvalue_hash[key];
       results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
     }
@@ -98,7 +98,7 @@ testIndGLMMGamma = function(target, reps = NULL, group, dataset, xIndex, csIndex
       }
     }
     
-  } else {
+  } else {  ## (length(cs) > 0)  
     if ( is.null(reps) ) {
       fit1 = lme4::glmer( target ~ (1|group) + cs, weights = wei, family = Gamma(log) )    
       fit2 = lme4::glmer( target ~ (1|group) + cs + x, weights = wei, family = Gamma(log) )    
