@@ -12,17 +12,17 @@ testIndGLMMReg = function(target, reps = NULL, group, dataset, xIndex, csIndex,
   #   csIndex: the indices of the variables to condition on. They can be mixed variables, either continous or categorical
   #   this method returns: the pvalue PVALUE, the statistic STAT.
   #cast factor into numeric vector
-  target = as.numeric(as.vector(target));
+  target <- as.numeric(as.vector(target));
   csIndex[which(is.na(csIndex))] = 0
   
   if( hash )  {
-    csIndex2 = csIndex[which(csIndex!=0)]
-    csIndex2 = sort(csIndex2)
-    xcs = c(xIndex,csIndex2)
-    key = paste(as.character(xcs) , collapse=" ");
-    if( !is.null(stat_hash[[key]]) )  {
-      stat = stat_hash[[key]];
-      pvalue = pvalue_hash[[key]];
+    csIndex2 <- csIndex[which(csIndex!=0)]
+    csIndex2 <- sort(csIndex2)
+    xcs <- c(xIndex,csIndex2)
+    key <- paste(as.character(xcs) , collapse=" ");
+    if( !is.null(stat_hash[key]) )  {
+      stat = stat_hash[key];
+      pvalue = pvalue_hash[key];
       results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
     }
@@ -46,9 +46,9 @@ testIndGLMMReg = function(target, reps = NULL, group, dataset, xIndex, csIndex,
     return(results);
   }
   #extract the data
-  x = dataset[ , xIndex];
-  cs = dataset[ , csIndex];
-  if(length(cs) == 0 || is.na(cs) )  cs = NULL;
+  x <- dataset[ , xIndex];
+  cs <- dataset[ , csIndex];
+  if (length(cs) == 0 || is.na(cs) )  cs = NULL;
   #That means that the x variable does not add more information to our model due to an exact copy of this in the cs, so it is independent from the target
   if ( length(cs) != 0 )  {
     if ( is.null(dim(cs)[2]) )  {     #cs is a vector
@@ -80,46 +80,47 @@ testIndGLMMReg = function(target, reps = NULL, group, dataset, xIndex, csIndex,
   if (length(cs) == 0)  {
     #if the univariate models have been already compute
     if ( !is.null(univariateModels) )  {
-      pvalue = univariateModels$pvalue[[xIndex]];
-      stat = univariateModels$stat[[xIndex]];
+      pvalue <- univariateModels$pvalue[[xIndex]];
+      stat <- univariateModels$stat[[xIndex]];
       results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
     }
    if ( is.null(reps) ) {
-      fit2 = lme4::lmer( target ~ (1|group) + x, weights = wei, REML = FALSE )
+      fit2 <- lme4::lmer( target ~ (1|group) + x, weights = wei, REML = FALSE )
    } else {
      reps <- reps 
      if ( slopes ) {
-       fit2 = lme4::lmer( target ~ reps + (reps|group) + x, weights = wei, REML = FALSE ) 	  
+       fit2 <- lme4::lmer( target ~ reps + (reps|group) + x, weights = wei, REML = FALSE ) 	  
      } else{
-       reps = reps 
-       fit2 = lme4::lmer( target ~ reps + (1|group) + x, weights = wei, REML = FALSE )        
+       reps <- reps 
+       fit2 <- lme4::lmer( target ~ reps + (1|group) + x, weights = wei, REML = FALSE )        
      }
    }
    
   } else {
     if ( is.null(reps) ) {
-       fit2 = lme4::lmer( target ~ (1|group) + cs + x, weights = wei, REML = FALSE )          
+       fit2 <- lme4::lmer( target ~ (1|group) + cs + x, weights = wei, REML = FALSE )          
     } else {
-      reps = reps 
+      reps <- reps 
       if (slopes ) {
-        fit2 = lme4::lmer( target ~ reps + (reps|group) + cs + x, weights = wei, REML = FALSE )
+        fit2 <- lme4::lmer( target ~ reps + (reps|group) + cs + x, weights = wei, REML = FALSE )
       } else {
-        fit2 = lme4::lmer( target ~ reps + (1|group) + cs + x, weights = wei, REML = FALSE )
+        fit2 <- lme4::lmer( target ~ reps + (1|group) + cs + x, weights = wei, REML = FALSE )
       }
     }
   }
   #calculate the p value and stat.
-  mod = anova(fit2)
-  v2 = as.numeric( summary(fit2)[[14]][5] )
-  pr = nrow(mod) 
-  v1 = mod[pr, 1]
-  if ( length(summary(fit2)[[17]]) > 0 ) {
-    stat <- 0
-    pvalue <- log(1)
+  dcs <- length(csIndex) + 1
+  if ( dcs < summary(fit2)[[ 3 ]]$dims[3] ) {
+    mod <- anova(fit2)
+    v2 <- as.numeric( summary(fit2)[[14]][5] )
+    pr <- nrow(mod) 
+    v1 <- mod[pr, 1]
+    stat <- mod[pr, 4]   
+    pvalue <- pf(stat, v1, v2, lower.tail = FALSE, log.p = TRUE)
   } else {
-    stat = mod[pr, 4]   
-    pvalue = pf(stat, v1, v2, lower.tail = FALSE, log.p = TRUE)
+    stat <- 0
+    pvalue <- log(1) 
   }	
   #update hash objects
   if ( hash )  {
