@@ -7,9 +7,9 @@ testIndTimeLogistic = function(target, dataset, xIndex, csIndex, wei = NULL, uni
     csIndex2 = sort(csIndex2)
     xcs = c(xIndex,csIndex2)
     key = paste(as.character(xcs) , collapse=" ");
-    if ( !is.null(stat_hash[[key]]) ) {
-      stat = stat_hash[[key]];
-      pvalue = pvalue_hash[[key]];
+    if ( !is.null(stat_hash[key]) ) {
+      stat = stat_hash[key];
+      pvalue = pvalue_hash[key];
       results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
     }
@@ -20,8 +20,8 @@ testIndTimeLogistic = function(target, dataset, xIndex, csIndex, wei = NULL, uni
   #information with respect to cs
   if ( !is.na( match(xIndex, csIndex) ) ) {
     if ( hash) {  #update hash objects
-      stat_hash[[key]] <- 0;     #.set(stat_hash , key , 0)
-      pvalue_hash[[key]] <- log(1);     #.set(pvalue_hash , key , 1)
+      stat_hash[key] <- 0;     #.set(stat_hash , key , 0)
+      pvalue_hash[key] <- log(1);     #.set(pvalue_hash , key , 1)
     }
     results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
     return(results);
@@ -43,8 +43,8 @@ testIndTimeLogistic = function(target, dataset, xIndex, csIndex, wei = NULL, uni
     if ( is.null(dim(cs)[2]) ) {  #cs is a vector
       if ( identical(x, cs) ) {  # if(!any(x == cs) == FALSE)
         if (hash) {     #update hash objects
-          stat_hash[[key]] <- 0;    #.set(stat_hash , key , 0)
-          pvalue_hash[[key]] <- log(1);    #.set(pvalue_hash , key , 1)
+          stat_hash[key] <- 0;    #.set(stat_hash , key , 0)
+          pvalue_hash[key] <- log(1);    #.set(pvalue_hash , key , 1)
         }
         results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
         return(results);
@@ -53,8 +53,8 @@ testIndTimeLogistic = function(target, dataset, xIndex, csIndex, wei = NULL, uni
       for ( col in 1:dim(cs)[2] ) {
         if ( identical( x, cs[, col] ) ) {  #if(!any(x == cs) == FALSE)
           if (hash) {    #update hash objects
-            stat_hash[[key]] <- 0;   #.set(stat_hash , key , 0)
-            pvalue_hash[[key]] <- log(1);   #.set(pvalue_hash , key , 1)
+            stat_hash[key] <- 0;   #.set(stat_hash , key , 0)
+            pvalue_hash[key] <- log(1);   #.set(pvalue_hash , key , 1)
           }
           results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
           return(results);
@@ -80,8 +80,8 @@ testIndTimeLogistic = function(target, dataset, xIndex, csIndex, wei = NULL, uni
   pvalue = pchisq(stat, 2, lower.tail = FALSE, log.p = TRUE); 
   #update hash objects
   if (hash) {
-    stat_hash[[key]] <- stat;      #.set(stat_hash , key , stat)
-    pvalue_hash[[key]] <- pvalue;     #.set(pvalue_hash , key , pvalue)
+    stat_hash[key] <- stat;      #.set(stat_hash , key , stat)
+    pvalue_hash[key] <- pvalue;     #.set(pvalue_hash , key , pvalue)
   }
   #last error check
   if ( is.na(pvalue) || is.na(stat) ) {
@@ -90,8 +90,8 @@ testIndTimeLogistic = function(target, dataset, xIndex, csIndex, wei = NULL, uni
   } else {
     #update hash objects
     if (hash) {
-      stat_hash[[key]] <- stat;      #.set(stat_hash , key , stat)
-      pvalue_hash[[key]] <- pvalue;      #.set(pvalue_hash , key , pvalue)
+      stat_hash[key] <- stat;      #.set(stat_hash , key , stat)
+      pvalue_hash[key] <- pvalue;      #.set(pvalue_hash , key , pvalue)
     }
   }
   #testerrorcaseintrycatch(4);
