@@ -9,9 +9,9 @@ waldPois = function(target, dataset, xIndex, csIndex, wei = NULL, univariateMode
     csIndex2 = sort(csIndex2)
     xcs = c(xIndex,csIndex2)
     key = paste(as.character(xcs) , collapse=" ");
-    if ( !is.null(stat_hash[[key]]) )  {
-      stat = stat_hash[[key]];
-      pvalue = pvalue_hash[[key]];
+    if ( !is.null(stat_hash[key]) )  {
+      stat = stat_hash[key];
+      pvalue = pvalue_hash[key];
       results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
     }
@@ -19,8 +19,8 @@ waldPois = function(target, dataset, xIndex, csIndex, wei = NULL, univariateMode
   #information with respect to cs
   if ( !is.na( match(xIndex, csIndex) ) ) {
     if ( hash )  {    #update hash objects
-      stat_hash[[key]] <- 0;     #.set(stat_hash , key , 0)
-      pvalue_hash[[key]] <- log(1);      #.set(pvalue_hash , key , 1)
+      stat_hash[key] <- 0;     #.set(stat_hash , key , 0)
+      pvalue_hash[key] <- log(1);      #.set(pvalue_hash , key , 1)
     }
     results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
     return(results);
@@ -41,8 +41,8 @@ waldPois = function(target, dataset, xIndex, csIndex, wei = NULL, univariateMode
     if ( is.null(dim(cs)[2]) ) { #cs is a vector
       if ( any(x != cs) == FALSE ) { #if(!any(x == cs) == FALSE)
         if (hash) {  #update hash objects
-          stat_hash[[key]] <- 0;   #.set(stat_hash , key , 0)
-          pvalue_hash[[key]] <- log(1);   #.set(pvalue_hash , key , 1)
+          stat_hash[key] <- 0;   #.set(stat_hash , key , 0)
+          pvalue_hash[key] <- log(1);   #.set(pvalue_hash , key , 1)
         }
         results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
         return(results);
@@ -51,8 +51,8 @@ waldPois = function(target, dataset, xIndex, csIndex, wei = NULL, univariateMode
       for (col in 1:dim(cs)[2])  {
         if (any(x != cs[, col]) == FALSE)  {  #if(!any(x == cs) == FALSE)
           if (hash) {  #update hash objects
-            stat_hash[[key]] <- 0;  #.set(stat_hash , key , 0)
-            pvalue_hash[[key]] <- log(1);   #.set(pvalue_hash , key , 1)
+            stat_hash[key] <- 0;  #.set(stat_hash , key , 0)
+            pvalue_hash[key] <- log(1);   #.set(pvalue_hash , key , 1)
           }
           results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
           return(results);
@@ -78,8 +78,8 @@ waldPois = function(target, dataset, xIndex, csIndex, wei = NULL, univariateMode
         stat = 0;
       } else {
         if (hash) {
-          stat_hash[[key]] <- stat;     #.set(stat_hash , key , stat)
-          pvalue_hash[[key]] <- pvalue;       #.set(pvalue_hash , key , pvalue)
+          stat_hash[key] <- stat;     #.set(stat_hash , key , stat)
+          pvalue_hash[key] <- pvalue;       #.set(pvalue_hash , key , pvalue)
         }
       }
       results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
